@@ -90,7 +90,8 @@ class Test_callinfo_methods:
     def test_get_homecall(self, fix_callinfo):
         assert fix_callinfo.get_homecall("HB9/DH1TW") == "DH1TW"
         assert fix_callinfo.get_homecall("SM3/DH1TW/P") == "DH1TW"
-        assert fix_callinfo.get_homecall("QRM") is None
+        with pytest.raises(ValueError):
+            fix_callinfo.get_homecall("QRM")
 
     def test_dismantle_callsign(self, fix_callinfo):
         if fix_callinfo._lookuplib._lookuptype == "clublogxml" or fix_callinfo._lookuplib._lookuptype == "countryfile":
